**Example 1: 查询专业版需购买信息**



Input: 

```
tccli tcss DescribeProVersionInfo --cli-unfold-argument ```

Output: 
```
{
    "Response": {
        "EndTime": "2021-05-01 00:00:00",
        "CoresCnt": 1,
        "MaxPostPayCoresCnt": 1,
        "StartTime": "2021-05-31 00:00:00",
        "ResourceId": "xx",
        "BuyStatus": "Normal",
        "IsPurchased": false,
        "RequestId": "xx"
    }
}
```

